@@ -1,7 +1,16 @@
+from typing import ClassVar
+
 from mxcubecore import HardwareRepository as HWR
+from mxcubecore.HardwareObjects.abstract import AbstractEnergy
 
 from mxcubeweb.core.adapter.actuator_adapter import ActuatorAdapter
 from mxcubeweb.core.adapter.wavelength_adapter import WavelengthAdapter
+from mxcubeweb.core.models.configmodels import AdapterResourceHandlerConfigModel
+
+resource_handler_config = AdapterResourceHandlerConfigModel(
+    commands=["get_value", "set_value", "stop", "get_resolution_limits_for_energy"],
+    attributes=["data"],
+)
 
 
 class EnergyAdapter(ActuatorAdapter):
@@ -10,12 +19,14 @@ class EnergyAdapter(ActuatorAdapter):
     information on longer running processes.
     """
 
-    def __init__(self, *args):
+    SUPPORTED_TYPES: ClassVar[list[object]] = [AbstractEnergy.AbstractEnergy]
+
+    def __init__(self, ho, role, app):
         """
         Args:
             (object): Hardware object.
         """
-        super().__init__(*args)
+        super().__init__(ho, role, app, resource_handler_config)
         self._add_adapter("wavelength", self._ho, WavelengthAdapter)
         self._type = "ENERGY"
 
