@@ -1,5 +1,11 @@
 import logging
 from enum import Enum
+from typing import ClassVar
+
+from mxcubecore.HardwareObjects.abstract import (
+    AbstractNState,
+    AbstractShutter,
+)
 
 from mxcubeweb.core.adapter.adapter_base import ActuatorAdapterBase
 from mxcubeweb.core.models.adaptermodels import (
@@ -7,15 +13,25 @@ from mxcubeweb.core.models.adaptermodels import (
     NStateModel,
     StrValueModel,
 )
+from mxcubeweb.core.models.configmodels import AdapterResourceHandlerConfigModel
+
+resource_handler_config = AdapterResourceHandlerConfigModel(
+    commands=["get_value", "set_value", "stop"], attributes=["data"]
+)
 
 
 class NStateAdapter(ActuatorAdapterBase):
-    def __init__(self, ho, *args):
+    SUPPORTED_TYPES: ClassVar[list[object]] = [
+        AbstractNState.AbstractNState,
+        AbstractShutter.AbstractShutter,
+    ]
+
+    def __init__(self, ho, role, app):
         """
         Args:
             (object): Hardware object.
         """
-        super().__init__(ho, *args)
+        super().__init__(ho, role, app, resource_handler_config)
         self._value_change_model = HOActuatorValueChangeModel
 
         ho.connect("valueChanged", self._value_change)
@@ -42,12 +58,18 @@ class NStateAdapter(ActuatorAdapterBase):
     def commands(self):
         return self._get_valid_states()
 
-    def _set_value(self, value: HOActuatorValueChangeModel):
+    def set_value(self, value: HOActuatorValueChangeModel):
         self._ho.set_value(self._ho.VALUES[value.value])
 
-    def _get_value(self) -> StrValueModel:
+    def get_value(self) -> StrValueModel:
         return StrValueModel(value=self._ho.get_value().name)
 
+    def stop(self):
+        """
+        Stop the execution.
+        """
+        self._ho.abort()
+
     def msg(self):
         try:
             msg = self._ho.get_value().name
