@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 import logging
 
 import gevent
@@ -43,21 +42,26 @@ class SampleChanger(ComponentBase):
             )
 
     def get_sample_list(self):
-        samples_list = HWR.beamline.sample_changer.get_sample_list()
+        samples_list = (
+            HWR.beamline.sample_changer.get_sample_list()
+            if HWR.beamline.sample_changer
+            else []
+        )
         samples = {}
         samplesByCoords = {}
         order = []
         current_sample = {}
 
-        loaded_sample = HWR.beamline.sample_changer.get_loaded_sample()
+        loaded_sample = (
+            HWR.beamline.sample_changer.get_loaded_sample()
+            if HWR.beamline.sample_changer
+            else None
+        )
 
         for s in samples_list:
             if not s.is_present():
                 continue
-            if s.has_been_loaded():
-                state = COLLECTED
-            else:
-                state = UNCOLLECTED
+            state = COLLECTED if s.has_been_loaded() else UNCOLLECTED
             sample_dm = s.get_id() or ""
             coords = s.get_coords()
             sample_data = {
@@ -141,9 +145,9 @@ class SampleChanger(ComponentBase):
             contents = {"name": root_name}
 
             if hasattr(HWR.beamline.sample_changer, "get_room_temperature_mode"):
-                contents[
-                    "room_temperature_mode"
-                ] = HWR.beamline.sample_changer.get_room_temperature_mode()
+                contents["room_temperature_mode"] = (
+                    HWR.beamline.sample_changer.get_room_temperature_mode()
+                )
 
             for element in HWR.beamline.sample_changer.get_components():
                 if element.is_present():
@@ -208,15 +212,14 @@ class SampleChanger(ComponentBase):
                 )
                 logging.getLogger("user_level_log").info(msg)
 
-                if not sc.get_loaded_sample():
-                    res = sc.load(sample["sampleID"], wait=True)
-                elif sc.get_loaded_sample().get_address() != sample["location"]:
+                if (
+                    not sc.get_loaded_sample()
+                    or sc.get_loaded_sample().get_address() != sample["location"]
+                ):
                     res = sc.load(sample["sampleID"], wait=True)
 
-                if res is None:
-                    res = True
                 if (
-                    res is not False
+                    res
                     and HWR.beamline.queue_manager.centring_method
                     == queue_entry.CENTRING_METHOD.LOOP
                     and not HWR.beamline.diffractometer.in_plate_mode()
@@ -267,7 +270,7 @@ class SampleChanger(ComponentBase):
         try:
             signals.sc_unload(sample["location"])
 
-            if not sample["location"] == "Manual":
+            if sample["location"] != "Manual":
                 HWR.beamline.sample_changer.unload(sample["location"], wait=False)
             else:
                 self.set_current_sample(None)
@@ -318,11 +321,10 @@ class SampleChanger(ComponentBase):
         num_samples = 0
         for basket in baskets:
             num_samples += basket.get_number_of_samples()
-        res = {
+        return {
             "num_baskets": len(baskets),
             "num_samples": num_samples,
         }
-        return res
 
     def get_maintenance_cmds(self):
         if HWR.beamline.sample_changer_maintenance is not None:
@@ -360,7 +362,7 @@ class SampleChanger(ComponentBase):
         except Exception:
             state = "OFFLINE"
 
-        initial_state = {
+        return {
             "state": state,
             "loaded_sample": loaded_sample,
             "contents": contents,
@@ -373,8 +375,6 @@ class SampleChanger(ComponentBase):
             "plate_mode": HWR.beamline.diffractometer.in_plate_mode(),
         }
 
-        return initial_state
-
     def sync_with_crims(self):
         """
         To be use mostly when Diffractometer is in plate mode
@@ -397,8 +397,7 @@ class SampleChanger(ComponentBase):
                     "sample": x.sample,
                 }
                 xtal_list.append(response)
-            res = {"xtal_list": xtal_list}
-            return res
+            return {"xtal_list": xtal_list}
         except Exception:
             logging.getLogger("MX3.HWR").exception("Could not get crystal List")
             return {"xtal_list": xtal_list}
