@@ -37,6 +37,21 @@ class FlaskConfigModel(BaseModel):
         "NONE",
         description="One of the strings ['SIGNED', 'ADHOC', NONE]",
     )
+    # Rate limiter configuration
+    RATE_LIMITER_ENABLED: bool = True
+    RATELIMIT_DEFAULT: str = "150000 per day;6000 per hour"
+    RATELIMIT_STORAGE_URI: str = "memory://"
+    RATELIMIT_HEADERS_ENABLED: bool = True
+
+    CSP_ENABLED: bool = True
+    CSP_POLICY: dict[str, list[str]] = {}
+    CSP_REPORT_ONLY: bool = Field(
+        False,
+        description="Set to True to enable report-only mode (won't block content)",
+    )
+    CSP_REPORT_URI: str = Field(
+        "", description="URI for CSP violation reports (empty to disable reporting)"
+    )
 
 
 class SSOConfigModel(BaseModel):
