@@ -22,6 +22,8 @@ from mxcubeweb.core.models.usermodels import (
     Role,
     User,
 )
+from mxcubeweb.core.server.csp import CSPMiddleware
+from mxcubeweb.core.server.limiter import init_limiter
 from mxcubeweb.core.server.resource_handler import AdapterResourceHandlerFactory
 from mxcubeweb.core.util import networkutils
 
@@ -34,6 +36,7 @@ class Server:
     user_datastore = None
     db_session = None
     flask_socketio = None
+    limiter = None
 
     def __init__(self):
         msg = "Server is to be used as a pure static class, don't instantiate."
@@ -57,8 +60,20 @@ class Server:
         )
         Server.flask.wsgi_app = ProxyFix(Server.flask.wsgi_app)
         Server.flask.config.from_object(cfg.flask)
+
         Server.flask.register_error_handler(Exception, Server.exception_handler)
 
+        if cfg.flask.CSP_ENABLED:
+            Server.flask.wsgi_app = CSPMiddleware(
+                Server.flask.wsgi_app,
+                {
+                    "CSP_ENABLED": cfg.flask.CSP_ENABLED,
+                    "CSP_POLICY": cfg.flask.CSP_POLICY,
+                    "CSP_REPORT_ONLY": cfg.flask.CSP_REPORT_ONLY,
+                    "CSP_REPORT_URI": cfg.flask.CSP_REPORT_URI,
+                },
+            )
+
         db_session = init_db(cfg.flask.USER_DB_PATH)
         Server.user_datastore = UserDatastore(
             db_session, User, Role, message_model=Message
@@ -72,6 +87,11 @@ class Server:
         )
         Server.flask_socketio.init_app(Server.flask)
 
+        if cfg.flask.RATE_LIMITER_ENABLED:
+            Server.limiter = init_limiter(Server.flask)
+        else:
+            Server.limiter = None
+
         # the following test prevents Flask from initializing twice
         # (because of the Reloader)
         if not Server.flask.debug or os.environ.get("WERKZEUG_RUN_MAIN") == "true":
@@ -98,6 +118,7 @@ class Server:
         )
 
         from mxcubeweb.routes.beamline import init_route as init_beamline_route
+        from mxcubeweb.routes.csp_report import init_route as init_csp_route
         from mxcubeweb.routes.detector import init_route as init_detector_route
         from mxcubeweb.routes.diffractometer import (
             init_route as init_diffractometer_route,
@@ -120,6 +141,7 @@ class Server:
         Server._register_route(
             init_beamline_route, mxcube, f"{url_root_prefix}/beamline"
         )
+        Server._register_route(init_csp_route, mxcube, f"{url_root_prefix}/csp")
 
         Server._register_route(
             init_detector_route, mxcube, f"{url_root_prefix}/detector"
